/* Request API endpoint to process the file upload */
function uploadFile(file) {
  const apiUrl = './../../../api/file-upload-ep.php';

  const formData = new FormData();
  formData.append('file', file);

  fetch(apiUrl, {
    method: 'POST',
    body: formData,
  })
    .then(response => response.text())
    .then(data => {
      // handle the API response here asynchronously
    })
    .catch(error => {
      console.error('Error:', error);
    });
}

/* Showing file preview based on the file extension */
function displayFilePreview(fileType, file, fileName) {
  const errorMessage = document.getElementById('error-message');
  if (fileType.startsWith("image/")) {
    // Display the image
    loadImagePreview(file, fileName);
  } else if (fileType === "application/pdf" || fileType === "application/vnd.openxmlformats-officedocument.wordprocessingml.document") {
    // Display the PDF or DOC icon as a link for download
    loadDocumentPreview(fileType, file, fileName);
  } else {
    // Error occurred if the file extension is not among the allowed file types
    errorMessage.textContent = "Unsupported file type: " + fileName;
  }
}

/* Creates image preview element dynamically and loads the file data url */
function loadImagePreview(file, fileName) {
  // Display the image
  const imageElement = document.createElement('img');
  imageElement.src = URL.createObjectURL(file);
  imageElement.style.width = '300px';
  linkFile(file, fileName, imageElement);
}

/* Creates doc/pdf preview dynamically and links to download the file */
function loadDocumentPreview(fileType, file, fileName) {
  const docCounter = document.createElement('p');
  reloadPreview(docCounter);
  const docPreviewIcon = new Image();
  if (fileType === "application/pdf") {
    docPreviewIcon.src = '/src/assets/image/pdf.png';
  } else {
    docPreviewIcon.src = '/src/assets/image/doc.png';
  }
  docPreviewIcon.style.maxWidth = '150px';
  linkFile(file, fileName, docPreviewIcon);
}

function linkFile(file, fileName, fileElement) {
  const fileLink = document.createElement('a');
  fileLink.href = URL.createObjectURL(file);
  fileLink.download = fileName;
  fileLink.appendChild(fileElement);
  reloadPreview(fileLink);
}

/* replaces the existing preview content with the latest */
function reloadPreview(previewElement) {
  const documentContainer = document.getElementById('file-preview');
  documentContainer.innerHTML = '';
  documentContainer.appendChild(previewElement);
}
